@@ -1,4 +1,5 @@
-from .exceptions import NotLoggedIn, InvalidCredentials
+from .exceptions import InvalidCredentials, NotLoggedIn
+
 import requests
 
 
